@@ -1225,15 +1225,6 @@ type CreateOrganizationInvitation struct {
 	Invitation Invitation
 }
 
-type LaunchMachineInput struct {
-	AppID   string         `json:"appId,omitempty"`
-	ID      string         `json:"id,omitempty"`
-	Name    string         `json:"name,omitempty"`
-	OrgSlug string         `json:"organizationId,omitempty"`
-	Region  string         `json:"region,omitempty"`
-	Config  *MachineConfig `json:"config"`
-}
-
 type GqlMachine struct {
 	ID     string
 	Name   string
